summaryrefslogtreecommitdiff
path: root/sw/source/ui/inc
diff options
context:
space:
mode:
authorJan Holesovsky <kendy@collabora.com>2013-10-16 16:36:45 +0200
committerJan Holesovsky <kendy@collabora.com>2013-10-16 16:57:22 +0200
commit66013a154bd2dccc0db1edd14197ce419ba9a614 (patch)
tree0698af88b8d236e98bafa6848f73851e0b752f15 /sw/source/ui/inc
parentd62b71bddedccb6ff29090f621cc0803565332ec (diff)
[API CHANGE]: PreView -> Preview, including .uno:PrintPagePreView.
Will be .uno:PrintPagePreview going forward. Change-Id: Ie5a35467917a54a60dab9eaacf0690c9df27e6f6
Diffstat (limited to 'sw/source/ui/inc')
-rw-r--r--sw/source/ui/inc/pview.hxx24
-rw-r--r--sw/source/ui/inc/view.hxx4
2 files changed, 14 insertions, 14 deletions
diff --git a/sw/source/ui/inc/pview.hxx b/sw/source/ui/inc/pview.hxx
index 12bc22cc56e8..7cf9e832dfca 100644
--- a/sw/source/ui/inc/pview.hxx
+++ b/sw/source/ui/inc/pview.hxx
@@ -32,7 +32,7 @@ class SwViewOption;
class SwDocShell;
class SwScrollbar;
class ViewShell;
-class SwPagePreView;
+class SwPagePreview;
class ImageButton;
class Button;
class SwRect;
@@ -42,14 +42,14 @@ class SvtAccessibilityOptions;
class SwPagePreviewLayout;
// Delete member <mnVirtPage> and its accessor
-class SwPagePreViewWin : public Window
+class SwPagePreviewWin : public Window
{
ViewShell* mpViewShell;
sal_uInt16 mnSttPage;
sal_uInt8 mnRow, mnCol;
Size maPxWinSize;
Fraction maScale;
- SwPagePreView& mrView;
+ SwPagePreview& mrView;
bool mbCalcScaleForPreviewLayout;
Rectangle maPaintedPreviewDocRect;
SwPagePreviewLayout* mpPgPreviewLayout;
@@ -59,8 +59,8 @@ class SwPagePreViewWin : public Window
using Window::Scroll;
public:
- SwPagePreViewWin( Window* pParent, SwPagePreView& rView );
- ~SwPagePreViewWin();
+ SwPagePreviewWin( Window* pParent, SwPagePreview& rView );
+ ~SwPagePreviewWin();
// calls ViewShell::Paint
virtual void Paint( const Rectangle& rRect );
@@ -145,14 +145,14 @@ public:
/**
* View of a document
*/
-class SW_DLLPUBLIC SwPagePreView: public SfxViewShell
+class SW_DLLPUBLIC SwPagePreview: public SfxViewShell
{
// ViewWindow and handle to core
// current dispatcher shell
- SwPagePreViewWin aViewWin;
+ SwPagePreviewWin aViewWin;
//viewdata of the previous SwView and the new crsrposition
OUString sSwViewData;
//and the new cursor position if the user double click in the PagePreView
OUString sNewCrsrPos;
// to support keyboard the number of the page to go to can be set too
sal_uInt16 nNewPage;
@@ -216,7 +216,7 @@ protected:
void SetZoom(SvxZoomType eSet, sal_uInt16 nFactor);
public:
- SFX_DECL_VIEWFACTORY(SwPagePreView);
+ SFX_DECL_VIEWFACTORY(SwPagePreview);
SFX_DECL_INTERFACE(SW_PAGEPREVIEW)
TYPEINFO();
@@ -286,12 +286,12 @@ public:
*/
void SetVScrollbarThumbPos( const sal_uInt16 _nNewThumbPos );
- SwPagePreView( SfxViewFrame* pFrame, SfxViewShell* );
- ~SwPagePreView();
+ SwPagePreview( SfxViewFrame* pFrame, SfxViewShell* );
+ ~SwPagePreview();
};
// ----------------- inline methods ----------------------
-inline void SwPagePreView::AdjustEditWin()
+inline void SwPagePreview::AdjustEditWin()
{
OuterResizePixel( Point(), GetFrameWindow()->GetOutputSizePixel() );
}
@@ -145,14 +145,14 @@ public:
//viewdata of the previous SwView and the new crsrposition
OUString sSwViewData;
- //and the new cursor position if the user double click in the PagePreView
+ //and the new cursor position if the user double click in the PagePreview
OUString sNewCrsrPos;
// to support keyboard the number of the page to go to can be set too
diff --git a/sw/source/ui/inc/view.hxx b/sw/source/ui/inc/view.hxx
index d6f9d9a365b3..3bad33f9ae0f 100644
--- a/sw/source/ui/inc/view.hxx
+++ b/sw/source/ui/inc/view.hxx
@@ -178,7 +178,7 @@ class SW_DLLPUBLIC SwView: public SfxViewShell
Timer m_aTimer; // for delayed ChgLnks during an action
OUString m_aPageStr; // status view, current page
OUString m_sSwViewData,
//and the new cursor position if the user double click in the PagePreView
m_sNewCrsrPos;
// to support keyboard the number of the page to go to can be set too
sal_uInt16 m_nNewPage;
@@ -265,7 +265,7 @@ class SW_DLLPUBLIC SwView: public SfxViewShell
m_bPasteSpecialState : 1,
m_bInMailMerge : 1,
m_bInDtor : 1, //detect destructor to prevent creating of sub shells while closing
- m_bOldShellWasPagePreView : 1,
+ m_bOldShellWasPagePreview : 1,
m_bIsPreviewDoubleClick : 1, // #i114045#
m_bMakeSelectionVisible : 1, // transport the bookmark selection
m_bAnnotationMode; ///< The real cursor position is inside an annotation.
@@ -178,7 +178,7 @@ class SW_DLLPUBLIC SwView: public SfxViewShell
OUString m_aPageStr; // status view, current page
OUString m_sSwViewData,
- //and the new cursor position if the user double click in the PagePreView
+ //and the new cursor position if the user double click in the PagePreview
m_sNewCrsrPos;
// to support keyboard the number of the page to go to can be set too